@@ -4,11 +4,11 @@ from functools import reduce
 import django
 from django.db.models import Q
 
-from .utils import (get_current_tenant, get_tenant_filters)
+from .utils import get_current_tenant, get_tenant_filters
 
 
 def related_objects(obj, *args):
-    if django.VERSION[0] < 3 or len(args) == 2:
+    if django.VERSION < (3, 0) or len(args) == 2:
         related = args[0]
         related_model = related.related_model
         related_fields = [related.field]
@@ -21,10 +21,13 @@ def related_objects(obj, *args):
         objs = args[2]
 
     filters = {}
-    predicate = reduce(operator.or_, (
-            Q(**{'%s__in' % related_field.name: objs})
+    predicate = reduce(
+        operator.or_,
+        (
+            Q(**{"%s__in" % related_field.name: objs})
             for related_field in related_fields
-        ))
+        ),
+    )
 
     if get_current_tenant():
         try:
