@@ -1,6 +1,7 @@
 import logging
 from django.apps import apps
 from django.db import models
+
 try:
     from threading import local
 except ImportError:
@@ -12,5 +13,4 @@ from collections import OrderedDict
 
 from .fields import TenantForeignKey, TenantOneToOneField
 from .models import TenantManager, TenantModel
-from .utils import (get_model_by_db_table,
-                    get_current_tenant, set_current_tenant)
+from .utils import get_model_by_db_table, get_current_tenant, set_current_tenant
